/*******************************************************************************
 * Copyright (c) 2005 Cognos Incorporated.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Cognos Incorporated - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.http.registry.internal;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.runtime.IExtensionRegistry;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.service.http.HttpService;
import org.osgi.service.packageadmin.PackageAdmin;
import org.osgi.util.tracker.ServiceTrackerCustomizer;

public class HttpServiceCustomizer implements ServiceTrackerCustomizer {

	private BundleContext context;
	private PackageAdmin packageAdmin;
	private IExtensionRegistry registry;

	private Map httpContextManagers = new HashMap();
	private Map servletManagers = new HashMap();
	private Map resourceManagers = new HashMap();

	public HttpServiceCustomizer(BundleContext context, PackageAdmin packageAdmin, IExtensionRegistry registry) {
		this.context = context;
		this.packageAdmin = packageAdmin;
		this.registry = registry;
	}

	public Object addingService(ServiceReference reference) {
		HttpService httpService = (HttpService) context.getService(reference);

		HttpContextManager httpContextManager = new HttpContextManager(httpService, packageAdmin, registry);
		httpContextManager.start();
		httpContextManagers.put(httpService, httpContextManager);

		ServletManager servletManager = new ServletManager(httpService, httpContextManager, registry);
		servletManager.start();
		servletManagers.put(httpService, servletManager);

		ResourceManager resourceManager = new ResourceManager(httpService, httpContextManager, registry);
		resourceManager.start();
		resourceManagers.put(httpService, resourceManager);

		return httpService;
	}

	public void modifiedService(ServiceReference reference, Object service) {
		// ignored
	}

	public void removedService(ServiceReference reference, Object service) {
		HttpContextManager httpContextManager = (HttpContextManager) httpContextManagers.remove(service);
		if (httpContextManager != null) {
			httpContextManager.stop();
		}

		ServletManager servletManager = (ServletManager) servletManagers.remove(service);
		if (servletManager != null) {
			servletManager.stop();
		}

		ResourceManager resourceManager = (ResourceManager) resourceManagers.remove(service);
		if (resourceManager != null) {
			resourceManager.stop();
		}
		context.ungetService(reference);
	}
}
