/*******************************************************************************
 * Copyright (c) 2005 Cognos Incorporated.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Cognos Incorporated - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.servlet.bridge.http.internal;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServlet;

import org.osgi.framework.*;
import org.osgi.service.http.HttpService;

public class Activator implements BundleActivator {

	private static final String BRIDGE_SERVLET_ENABLED = "org.eclipse.equinox.servlet.bridge.enabled"; //$NON-NLS-1$
	private static final String BRIDGE_SERVLET_CLASS = "org.eclipse.equinox.servlet.bridge.launcher.BridgeServlet"; //$NON-NLS-1$
	private static final String UNREGISTER_SERVLET_DELEGATE = "unregisterServletDelegate"; //$NON-NLS-1$
	private static final String REGISTER_SERVLET_DELEGATE = "registerServletDelegate"; //$NON-NLS-1$

	private static BundleContext context;
	private static Map serviceRegistrations = new HashMap();
	private ProxyServlet proxy;

	public void start(BundleContext context) throws Exception {		
		startHttpServiceProxy(context);
		if (Boolean.valueOf(context.getProperty(BRIDGE_SERVLET_ENABLED)).booleanValue()) {
			proxy = new ProxyServlet();
			Class clazz = Activator.class.getClassLoader().loadClass(BRIDGE_SERVLET_CLASS);
			Method registerServletDelegate = clazz.getMethod(REGISTER_SERVLET_DELEGATE, new Class[] {HttpServlet.class});
			registerServletDelegate.invoke(null, new Object[] {proxy});
		}
	}

	public void stop(BundleContext context) throws Exception {
		if (Boolean.valueOf(context.getProperty(BRIDGE_SERVLET_ENABLED)).booleanValue()) {
			Class clazz = Activator.class.getClassLoader().loadClass(BRIDGE_SERVLET_CLASS);
			Method unregisterServletDelegate = clazz.getMethod(UNREGISTER_SERVLET_DELEGATE, new Class[] {HttpServlet.class});
			unregisterServletDelegate.invoke(null, new Object[] {proxy});
		}
		stopHttpServiceProxy(context);
	}	
	
	private static synchronized void startHttpServiceProxy(BundleContext bundleContext) {
		context = bundleContext;
		Object[] proxyServlets = serviceRegistrations.keySet().toArray();
		for (int i=0;i < proxyServlets.length; ++i) {
			HttpServiceFactory factory = new HttpServiceFactory((ProxyServlet) proxyServlets[i]);
			ServiceRegistration registration = context.registerService(HttpService.class.getName(), factory, null);
			serviceRegistrations.put(proxyServlets[i], registration);
		}
	}

	private static synchronized void stopHttpServiceProxy(BundleContext bundleContext) {
		Object[] proxyServlets = serviceRegistrations.keySet().toArray();
		for (int i=0;i < proxyServlets.length; ++i) {
			ServiceRegistration registration = (ServiceRegistration) serviceRegistrations.put(proxyServlets[i], null);
			registration.unregister();
		}
		context = null;
	}	

	static synchronized void addProxyServlet(ProxyServlet proxyServlet) {
		ServiceRegistration registration = null;
		if (context != null) {
			HttpServiceFactory factory = new HttpServiceFactory(proxyServlet);
			registration = context.registerService(HttpService.class.getName(), factory, null);
		}
		serviceRegistrations.put(proxyServlet, registration);
	}

	static synchronized void removeProxyServlet(ProxyServlet proxyServlet) {
		ServiceRegistration registration = (ServiceRegistration) serviceRegistrations.remove(proxyServlet);
		if (registration != null)
			registration.unregister();
	}	
}
