/*******************************************************************************
 * Copyright (c) 2005 Cognos Incorporated.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Cognos Incorporated - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.servlet.bridge.http.internal;

import java.util.*;
import javax.servlet.Servlet;
import javax.servlet.ServletException;
import org.osgi.framework.Bundle;
import org.osgi.service.http.*;

public class HttpServiceImpl implements HttpService {

	private Bundle bundle;

	private ProxyServlet proxy;

	Set aliases = new HashSet();

	public HttpServiceImpl(Bundle bundle, ProxyServlet proxy) {
		this.bundle = bundle;
		this.proxy = proxy;
	}

	public synchronized void unregisterAliases() {
		for (Iterator it = aliases.iterator(); it.hasNext();) {
			String alias = (String) it.next();
			proxy.unregister(alias, false);
		}
		aliases.clear();
	}

	public synchronized void registerServlet(String alias, Servlet servlet, Dictionary initparams, HttpContext context) throws ServletException, NamespaceException {
		if (context == null) {
			context = new DefaultHttpContext(bundle);
		}
		proxy.registerServlet(alias, servlet, initparams, context, bundle);
		aliases.add(alias);
	}

	public synchronized void registerResources(String alias, String name, HttpContext context) throws NamespaceException {
		if (context == null) {
			context = new DefaultHttpContext(bundle);
		}
		proxy.registerResources(alias, name, context);
		aliases.add(alias);
	}

	public synchronized void unregister(String alias) {
		if (aliases.remove(alias)) {
			proxy.unregister(alias, true);
		} else {
			// TODO perhaps this is too strong a reacttion ?
			throw new IllegalArgumentException("Alias not found."); //$NON-NLS-1$
		}
	}

	public HttpContext createDefaultHttpContext() {
		return new DefaultHttpContext(bundle);
	}
}
