/*******************************************************************************
 * Copyright (c) 2005 Cognos Incorporated.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Cognos Incorporated - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.servlet.bridge.http.internal;

import java.io.*;
import java.net.URL;
import java.security.*;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.osgi.service.http.HttpContext;

public class ResourceRegistration extends Registration {

	private String internalName;
	HttpContext httpContext;
	private ServletContext servletContext;
	private AccessControlContext acc;

	public ResourceRegistration(String internalName, HttpContext context, ServletContext servletContext, AccessControlContext acc) {
		this.internalName = internalName;
		if (internalName == null || internalName.equals("/")) { //$NON-NLS-1$
			this.internalName = ""; //$NON-NLS-1$
		}
		this.httpContext = context;
		this.servletContext = servletContext;
		this.acc = acc;
	}

	public boolean handleRequest(HttpServletRequest req, final HttpServletResponse resp, String alias) throws IOException {
		if (httpContext.handleSecurity(req, resp)) {

			String method = req.getMethod();
			if (method.equals("GET") || method.equals("POST") || method.equals("HEAD")) { //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$

				String pathInfo = HttpServletRequestAdaptor.getDispatchPathInfo(req);
				int aliasLength = alias.equals("/") ? 0 : alias.length(); //$NON-NLS-1$
				String bundlePath = internalName + pathInfo.substring(aliasLength);
				URL testURL = httpContext.getResource(bundlePath);
				if (testURL == null) {
					return false;
				}

				String contentType = httpContext.getMimeType(bundlePath);
				if (contentType == null) {
					contentType = servletContext.getMimeType(bundlePath);
				}

				if (contentType != null) {
					resp.setContentType(contentType);
				}
				return writeResource(resp, bundlePath);
			}
			resp.setStatus(HttpServletResponse.SC_METHOD_NOT_ALLOWED);
		}
		return true;
	}

	private boolean writeResource(final HttpServletResponse resp, final String bundlePath) throws IOException {
		Boolean result = Boolean.TRUE;
		try {
			result = (Boolean) AccessController.doPrivileged(new PrivilegedExceptionAction() {

				public Object run() throws Exception {
					URL url = httpContext.getResource(bundlePath);
					if (url == null) {
						return Boolean.FALSE;
					}
					InputStream is = null;
					try {
						is = url.openStream();
						OutputStream os = resp.getOutputStream();
						byte[] buffer = new byte[8192];
						int bytesRead = is.read(buffer);
						int contentLength = 0;
						while (bytesRead != -1) {
							os.write(buffer, 0, bytesRead);
							contentLength += bytesRead;
							bytesRead = is.read(buffer);
						}
						resp.setContentLength(contentLength);
					} finally {
						if (is != null)
							is.close();
					}
					return Boolean.TRUE;
				}
			}, acc);
		} catch (PrivilegedActionException e) {
			throw (IOException) e.getException();
		}
		return result.booleanValue();
	}

}
