/*******************************************************************************
 * Copyright (c) 2005 Cognos Incorporated.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Cognos Incorporated - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.servlet.bridge.http.internal;

import java.io.IOException;
import java.net.URL;
import java.util.Enumeration;
import java.util.Set;
import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.osgi.framework.Bundle;
import org.osgi.service.http.HttpContext;

public class ServletRegistration extends Registration {

	private Servlet servlet;
	private HttpContext httpContext;
	private Set servlets;
	private BundleProxyClassLoader bundleContextClassLoader;

	public ServletRegistration(Servlet servlet, HttpContext context, Bundle bundle, Set servlets) {
		this.servlet = servlet;
		this.servlets = servlets;
		this.httpContext = context;
		bundleContextClassLoader = new BundleProxyClassLoader(bundle, Thread.currentThread().getContextClassLoader());
	}

	public void destroy() {
		ClassLoader original = Thread.currentThread().getContextClassLoader();
		try {
			Thread.currentThread().setContextClassLoader(bundleContextClassLoader);
			super.destroy();
		} finally {
			Thread.currentThread().setContextClassLoader(original);
		}
		servlet.destroy();
	}

	public void close() {
		servlets.remove(servlet);
	}

	public void init(ServletConfig servletConfig) throws ServletException {
		ClassLoader original = Thread.currentThread().getContextClassLoader();
		try {
			Thread.currentThread().setContextClassLoader(bundleContextClassLoader);
			servlet.init(servletConfig);
		} finally {
			Thread.currentThread().setContextClassLoader(original);
		}
		servlets.add(servlet);
	}

	public void checkServletRegistration() throws ServletException {
		if (servlets.contains(servlet)) {
			throw new ServletException("This servlet has already been registered at a different alias."); //$NON-NLS-1$
		}
	}

	public boolean handleRequest(HttpServletRequest req, HttpServletResponse resp, String alias) throws IOException, ServletException {
		HttpServletRequest wrappedRequest = new HttpServletRequestAdaptor(req, alias, servlet);

		if (httpContext.handleSecurity(wrappedRequest, resp)) {
			ClassLoader original = Thread.currentThread().getContextClassLoader();
			try {
				Thread.currentThread().setContextClassLoader(bundleContextClassLoader);
				servlet.service(wrappedRequest, resp);
			} finally {
				Thread.currentThread().setContextClassLoader(original);
			}
		}
		return true;
	}

	private static class BundleProxyClassLoader extends ClassLoader {
		private Bundle bundle;
		private ClassLoader parent;

		public BundleProxyClassLoader(Bundle bundle) {
			this.bundle = bundle;
		}

		public BundleProxyClassLoader(Bundle bundle, ClassLoader parent) {
			super(parent);
			this.parent = parent;
			this.bundle = bundle;
		}

		public Enumeration findResources(String name) throws IOException {
			return bundle.getResources(name);
		}

		public URL findResource(String name) {
			return bundle.getResource(name);
		}

		public Class findClass(String name) throws ClassNotFoundException {
			return bundle.loadClass(name);
		}

		public URL getResource(String name) {
			return (parent == null) ? findResource(name) : super.getResource(name);
		}

		public Class loadClass(String name) throws ClassNotFoundException {
			return (parent == null) ? findClass(name) : super.loadClass(name);
		}
	}
}
