package org.eclipse.example.rcpmail;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.springframework.context.ApplicationContext;
import org.springframework.osgi.context.support.AbstractBundleXmlApplicationContext;
import org.springframework.osgi.service.OsgiServiceUtils;

/**
 * The activator class controls the plug-in life cycle
 */
public class Activator extends AbstractUIPlugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.eclipse.example.rcpmail";

	// The shared instance
	private static Activator plugin;
	private BundleContext context;
	
	/**
	 * The constructor
	 */
	public Activator() {
		plugin = this;
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		this.context = context;
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}

	/**
	 * Returns an image descriptor for the image file at the given
	 * plug-in relative path
	 *
	 * @param path the path
	 * @return the image descriptor
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}
	
	public static ApplicationContext getApplicationContext() {
		if (plugin != null) {
			String filter = "(" + AbstractBundleXmlApplicationContext.APPLICATION_CONTEXT_SERVICE_NAME_HEADER +
								"=org.eclipse.example.rcpmail-springApplicationContext)";
			ServiceReference ref = OsgiServiceUtils.getService(plugin.context, ApplicationContext.class, filter);
			ApplicationContext springContext = (ApplicationContext) plugin.context.getService(ref);
			return springContext;
		}
		else {
			throw new RuntimeException("Bundle not activated");
		}
	}

}
